# eric7.Plugins.VcsPlugins.vcsMercurial.GpgExtension.HgGpgSignaturesDialog

Module implementing a dialog showing signed changesets.

### Global Attributes

None

### Classes

HgGpgSignaturesDialog | Class implementing a dialog showing signed changesets.

### Functions

None

## HgGpgSignaturesDialog

Class implementing a dialog showing signed changesets.

### Derived from

QDialog, Ui_HgGpgSignaturesDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgGpgSignaturesDialog | Constructor
__filterSignatures | Private method to filter the log entries.
__finish | Private slot called when the process finished or the user pressed the button.
__generateItem | Private method to generate a patch item in the list of patches.
__processOutputLine | Private method to process the lines of output.
__resizeColumns | Private method to resize the list columns.
__resort | Private method to resort the tree.
__showError | Private slot to show some error.
closeEvent | Protected slot implementing a close event handler.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
on_categoryCombo_activated | Private slot called, when a new filter category is selected.
on_rxEdit_textChanged | Private slot called, when a filter expression is entered.
on_signaturesList_itemSelectionChanged | Private slot handling changes of the selection.
on_verifyButton_clicked | Private slot to verify the signatures of the selected revision.
start | Public slot to start the list command.

### Static Methods

None

#### HgGpgSignaturesDialog (Constructor)

HgGpgSignaturesDialog(vcs, parent=None)

Constructor

vcs
  reference to the vcs object
parent
  reference to the parent widget (QWidget)

#### HgGpgSignaturesDialog.__filterSignatures

__filterSignatures()

Private method to filter the log entries.

#### HgGpgSignaturesDialog.__finish

__finish()

Private slot called when the process finished or the user pressed the button.

#### HgGpgSignaturesDialog.__generateItem

__generateItem(revision, changeset, signature)

Private method to generate a patch item in the list of patches.

revision
  revision number (string)
changeset
  changeset of the bookmark (string)
signature
  signature of the changeset (string)

#### HgGpgSignaturesDialog.__processOutputLine

__processOutputLine(line)

Private method to process the lines of output.

line
  output line to be processed (string)

#### HgGpgSignaturesDialog.__resizeColumns

__resizeColumns()

Private method to resize the list columns.

#### HgGpgSignaturesDialog.__resort

__resort()

Private method to resort the tree.

#### HgGpgSignaturesDialog.__showError

__showError(out)

Private slot to show some error.

out
  error to be shown (string)

#### HgGpgSignaturesDialog.closeEvent

closeEvent(e)

Protected slot implementing a close event handler.

e
  close event (QCloseEvent)

#### HgGpgSignaturesDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button
  button that was clicked (QAbstractButton)

#### HgGpgSignaturesDialog.on_categoryCombo_activated

on_categoryCombo_activated(index)

Private slot called, when a new filter category is selected.

index (int)
  index of the selected entry

#### HgGpgSignaturesDialog.on_rxEdit_textChanged

on_rxEdit_textChanged(txt)

Private slot called, when a filter expression is entered.

txt
  filter expression (string)

#### HgGpgSignaturesDialog.on_signaturesList_itemSelectionChanged

on_signaturesList_itemSelectionChanged()

Private slot handling changes of the selection.

#### HgGpgSignaturesDialog.on_verifyButton_clicked

on_verifyButton_clicked()

Private slot to verify the signatures of the selected revision.

#### HgGpgSignaturesDialog.start

start()

Public slot to start the list command.

Up